lns2ewma.crit(l,L0,df,sigma0=1,cl=NULL,cu=NULL,hs=NULL,sided="upper",mode="fixed",r=40)sided="upper", that is, upper variance control chart with
lower reflecting barrier cl.sided="two") and fixed upper control limit (mode="fixed"),
for all other cases cu is ignored."upper" (upper chart with reflection at cl),
"lower" (lower chart with reflection at cu), and "two" sided="two" -- with "fixed" an upper control limit (see cu)
is set and only the lower is
calculated to obtain the in-control ARL L0, while with "unbiased" a cecl and cu.lns2ewma.crit determines the critical values (similar to alarm limits) for given in-control ARL L0
by applying secant rule and using lns2ewma.arl().
In case of sided="two" and mode="unbiased"
a two-dimensional secant rule is applied that also ensures that the
maximum of the ARL function for given standard deviation is attained
at sigma0. See Knoth (2010) and the related example.S. V. Crowder and M. D. Hamilton (1992), An EWMA for monitoring a process standard deviation, Journal of Quality Technology 24, 12-21.
S. Knoth (2005), Accurate ARL computation for EWMA-$S^2$ control charts, Statistics and Computing 15, 341-352.
S. Knoth (2010), Control Charting Normal Variance -- Reflections, Curiosities, and Recommendations, in Frontiers in Statistical Quality Control 9, H.-J. Lenz and P.-T. Wilrich (Eds.), Physica Verlag, Heidelberg, Germany, 3-18.
lns2ewma.arl for calculation of ARL of EWMA ln $S^2$ control charts.## Knoth (2005)
## compare with Table 3 (p. 351)
L0 <- 200
l <- .05
df <- 4
limits <- lns2ewma.crit(l, L0, df, cl=0, hs=0)
limits["cu"]Run the code above in your browser using DataLab