Learn R Programming

spc (version 0.5.2)

mewma.crit: Compute alarm threshold of MEWMA control charts

Description

Computation of the alarm threshold for multivariate exponentially weighted moving average (MEWMA) charts monitoring multivariate normal mean.

Usage

mewma.crit(l, L0, p, hs=0, r=20)

Arguments

l
smoothing parameter lambda of the MEWMA control chart.
L0
in-control ARL.
p
dimension of multivariate normal distribution.
hs
so-called headstart (enables fast initial response) -- must be non-negative.
r
number of quadrature nodes -- dimension of the resulting linear equation system.

Value

  • Returns a single value which resembles the critical value c.

Details

mewma.crit determines the alarm threshold of for given in-control ARL L0 by applying secant rule and using mewma.arl() with ntype="gl2".

References

Steven E. Rigdon (1995), An integral equation for the in-control average run length of a multivariate exponentially weighted moving average control chart, J. Stat. Comput. Simulation 52, 351-365.

See Also

mewma.arl for zero-state ARL computation.

Examples

Run this code
# Rigdon (1995), p. 358, Tab. 1
p <- 4
L0 <- 500
r <- .25
h4 <- mewma.crit(r, L0, p)
h4
## original value is 16.38.

Run the code above in your browser using DataLab