Learn R Programming

spc (version 0.5.2)

mewma.psi: Compute steady-state density of the MEWMA statistic

Description

Computation of the (zero-state) steady-state density function of the statistic deployed in multivariate exponentially weighted moving average (MEWMA) charts monitoring multivariate normal mean.

Usage

mewma.psi(l, cE, p, type="cond", hs=0, r=20)

Arguments

l
smoothing parameter lambda of the MEWMA control chart.
cE
alarm threshold of the MEWMA control chart.
p
dimension of multivariate normal distribution.
type
switch between "cond" and "cycl" for differentiating between the conditional (no false alarm) and the cyclical (after false alarm re-start in hs), respectively.
hs
the re-starting point for the cyclical steady-state framework.
r
number of quadrature nodes.

Value

  • Returns a function.

Details

Basically, ideas from Knoth (2015, MEWMA numerics) and Knoth (2014, steady-state ARL concepts) are merged. More details will follow.

References

Sven Knoth (2014), The Case Against the Use of Synthetic Control Charts, accepted in Journal of Quality Technology.

Sven Knoth (2015), ARL numerics for MEWMA charts, under revision in Journal of Quality Technology.

See Also

mewma.arl for calculating the in-control ARL of MEWMA.

Examples

Run this code
lambda <- 0.1
L0 <- 1000
p <- 3
h4 <- mewma.crit(lambda, L0, p)
x_ <- seq(0, h4*lambda/(2-lambda), by=0.002)
psi <- mewma.psi(lambda, h4, p)
psi_ <- psi(x_)
#plot(x_, psi_, type="l", xlab="x", ylab=expression(psi(x)))

Run the code above in your browser using DataLab