Learn R Programming

spc (version 0.5.2)

sewma.arl.prerun: Compute ARLs of EWMA control charts (variance charts) in case of estimated parameters

Description

Computation of the (zero-state) Average Run Length (ARL) for EWMA control charts (based on the sample variance $S^2$) monitoring normal variance with estimated parameters.

Usage

sewma.arl.prerun(l, cl, cu, sigma, df1, df2, hs=1, sided="upper",
r=40, qm=30, qm.sigma=30, truncate=1e-10)

Arguments

l
smoothing parameter lambda of the EWMA control chart.
cl
lower control limit of the EWMA control chart.
cu
upper control limit of the EWMA control chart.
sigma
true standard deviation.
df1
actual degrees of freedom, corresponds to subgroup size (for known mean it is equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
df2
degrees of freedom of the pre-run variance estimator.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts by choosing "upper" (upper chart without reflection at cl -- the actual value of cl is not used), "Rupper" (upper chart with
r
dimension of the resulting linear equation system (highest order of the collocation polynomials).
qm
number of quadrature nodes for calculating the collocation definite integrals.
qm.sigma
number of quadrature nodes for convoluting the standard deviation uncertainty.
truncate
size of truncated tail.

Value

  • Returns a single value which resembles the ARL.

Details

Essentially, the ARL function sewma.arl is convoluted with the distribution of the sample standard deviation. For details see Jones/Champ/Rigdon (2001) and Knoth (2014?).

References

L. A. Jones, C. W. Champ, S. E. Rigdon (2001), The performance of exponentially weighted moving average charts with estimated parameters, Technometrics 43, 156-167.

S. Knoth (2005), Accurate ARL computation for EWMA-$S^2$ control charts, Statistics and Computing 15, 341-352.

S. Knoth (2006), Computation of the ARL for CUSUM-$S^2$ schemes, Computational Statistics & Data Analysis 51, 499-512.

See Also

sewma.arl for zero-state ARL function of EWMA control charts w/o pre run uncertainty.

Examples

Run this code
## Knoth (2014?)

Run the code above in your browser using DataLab