Learn R Programming

spc (version 0.5.2)

sewma.crit.prerun: Compute critical values of of EWMA (variance charts) control charts under pre-run uncertainty

Description

Computation of quantiles of the Run Length (RL) for EWMA control charts monitoring normal variance.

Usage

sewma.crit.prerun(l,L0,df1,df2,sigma0=1,cl=NULL,cu=NULL,hs=1,sided="upper",
mode="fixed",r=40,qm=30,qm.sigma=30,truncate=1e-10,
tail_approx=TRUE,c.error=1e-10,a.error=1e-9)

Arguments

l
smoothing parameter lambda of the EWMA control chart.
L0
in-control quantile value.
df1
actual degrees of freedom, corresponds to subgroup size (for known mean it is equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
df2
degrees of freedom of the pre-run variance estimator.
sigma,sigma0
true and in-control standard deviation, respectively.
cl
deployed for sided="Rupper", that is, upper variance control chart with lower reflecting barrier cl.
cu
for two-sided (sided="two") and fixed upper control limit (mode="fixed") a value larger than sigma0 has to been given, for all other cases cu is ignored.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts by choosing "upper" (upper chart without reflection at cl -- the actual value of cl is not used), "Rupper" (upper chart with r
mode
only deployed for sided="two" -- with "fixed" an upper control limit (see cu) is set and only the lower is calculated to obtain the in-control ARL L0, while with "unbiased" a ce
r
dimension of the resulting linear equation system (highest order of the collocation polynomials).
qm
number of quadrature nodes for calculating the collocation definite integrals.
qm.sigma
number of quadrature nodes for convoluting the standard deviation uncertainty.
truncate
size of truncated tail.
tail_approx
controls whether the geometric tail approximation is used (is faster) or not.
c.error
error bound for two succeeding values of the critical value during applying the secant rule.
a.error
error bound for the quantile level alpha during applying the secant rule.

Value

  • Returns the lower and upper control limit cl and cu.

Details

sewma.crit.prerun determines the critical values (similar to alarm limits) for given in-control ARL L0 by applying secant rule and using sewma.arl.prerun(). In case of sided="two" and mode="unbiased" a two-dimensional secant rule is applied that also ensures that the maximum of the ARL function for given standard deviation is attained at sigma0. See Knoth (2010) for some details of the algorithm involved.

References

H.-J. Mittag and D. Stemann and B. Tewes (1998), EWMA-Karten zur "Uberwachung der Streuung von Qualit"atsmerkmalen, Allgemeines Statistisches Archiv 82, 327-338, S. Knoth (2005), Accurate ARL computation for EWMA-$S^2$ control charts, Statistics and Computing 15, 341-352.

S. Knoth (2010), Control Charting Normal Variance -- Reflections, Curiosities, and Recommendations, in Frontiers in Statistical Quality Control 9, H.-J. Lenz and P.-T. Wilrich (Eds.), Physica Verlag, Heidelberg, Germany, 3-18.

See Also

sewma.arl.prerun for calculation of ARL of variance charts under pre-run uncertainty and sewma.crit for the algorithm w/o pre-run uncertainty.

Examples

Run this code
## Knoth (2014?)

Run the code above in your browser using DataLab