sewma.q(l, cl, cu, sigma, df, alpha, hs=1, sided="upper", r=40, qm=30)sewma.q.crit(l,L0,alpha,df,sigma0=1,cl=NULL,cu=NULL,hs=1,sided="upper",
mode="fixed",ur=4,r=40,qm=30,c.error=1e-12,a.error=1e-9)
sided="Rupper", that is, upper variance control
chart with lower reflecting barrier cl.sided="two") and fixed upper control limit
(mode="fixed") a value larger than sigma0
has to been given, for all other cases cu is ignored."upper" (upper chart
without reflection at cl -- the actual value of cl is not used), "Rupper"
(upper chart with rsided="two" -- with "fixed" an upper
control limit (see cu) is set and only the lower is
calculated to obtain the in-control ARL L0, while with "unbiased" a
ceclassic mode.alpha
during applying the secant rule.alpha and
the lower and upper control limit cl and cu, respectively.sewma.q.crit determines the critical values (similar to alarm limits)
for given in-control RL quantile L0 at level alpha by applying
secant rule and using sewma.sf().
In case of sided="two" and mode="unbiased" a two-dimensional
secant rule is applied that also ensures that the
minimum of the cdf for given standard deviation is attained at sigma0.C. A. Acosta-Mej'ia and J. J. Pignatiello Jr. and B. V. Rao (1999), A comparison of control charting procedures for monitoring process dispersion, IIE Transactions 31, 569-579.
S. Knoth (2005), Accurate ARL computation for EWMA-$S^2$ control charts, Statistics and Computing 15, 341-352.
S. Knoth (2007), Accurate ARL calculation for EWMA control charts monitoring simultaneously normal mean and variance, Sequential Analysis 26, 251-264.
S. Knoth (2010), Control Charting Normal Variance -- Reflections, Curiosities, and Recommendations, in Frontiers in Statistical Quality Control 9, H.-J. Lenz and P.-T. Wilrich (Eds.), Physica Verlag, Heidelberg, Germany, 3-18.
K.-H. Waldmann (1986), Bounds for the distribution of the run length of geometric moving average charts, Appl. Statist. 35, 151-158.
sewma.arl for calculation of ARL of variance charts and
sewma.sf for the RL survival function.