sewma.q.prerun(l,cl,cu,sigma,df1,df2,alpha,hs=1,sided="upper",
r=40,qm=30,qm.sigma=30,truncate=1e-10)sewma.q.crit.prerun(l,L0,alpha,df1,df2,sigma0=1,cl=NULL,cu=NULL,hs=1,
sided="upper",mode="fixed",r=40, qm=30,qm.sigma=30,truncate=1e-10,
tail_approx=TRUE,c.error=1e-10,a.error=1e-9)
sided="Rupper", that is, upper variance control chart
with lower reflecting barrier cl.sided="two") and fixed upper control limit
(mode="fixed") a value larger than sigma0
has to been given, for all other cases cu is ignored."upper" (upper chart
without reflection at cl -- the actual value of cl is not used),
"Rupper" (upper chart with rsided="two" -- with "fixed"
an upper control limit (see cu) is set and only the lower is
calculated to obtain the in-control ARL L0, while with "unbiased" a cealpha during applying the secant rule.alpha and
the lower and upper control limit cl and cu, respectively.sewma.q.crit.prerun determines the critical values (similar to alarm limits)
for given in-control RL quantile L0 at level alpha by applying secant
rule and using sewma.sf().
In case of sided="two" and mode="unbiased"
a two-dimensional secant rule is applied that also ensures that the
minimum of the cdf for given standard deviation is attained at sigma0.K.-H. Waldmann (1986), Bounds for the distribution of the run length of geometric moving average charts, Appl. Statist. 35, 151-158.
sewma.q and sewma.q.crit for the version w/o pre-run uncertainty.