Learn R Programming

spc (version 0.5.2)

sewma.sf: Compute the survival function of EWMA run length

Description

Computation of the survival function of the Run Length (RL) for EWMA control charts monitoring normal variance.

Usage

sewma.sf(n, l, cl, cu, sigma, df, hs=1, sided="upper", r=40, qm=30)

Arguments

n
calculate sf up to value n.
l
smoothing parameter lambda of the EWMA control chart.
cl
lower control limit of the EWMA control chart.
cu
upper control limit of the EWMA control chart.
sigma
true standard deviation.
df
actual degrees of freedom, corresponds to subgroup size (for known mean it is equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts by choosing "upper" (upper chart without reflection at cl -- the actual value of cl is not used), "Rupper" (upper chart with
r
dimension of the resulting linear equation system (highest order of the collocation polynomials).
qm
number of quadrature nodes for calculating the collocation definite integrals.

Value

  • Returns a vector which resembles the survival function up to a certain point.

Details

The survival function P(L>n) and derived from it also the cdf P(L

References

S. Knoth (2007), Accurate ARL calculation for EWMA control charts monitoring simultaneously normal mean and variance, Sequential Analysis 26, 251-264.

K.-H. Waldmann (1986), Bounds for the distribution of the run length of geometric moving average charts, Appl. Statist. 35, 151-158.

See Also

sewma.arl for zero-state ARL computation of variance EWMA control charts.

Examples

Run this code
## Knoth (2014?)

Run the code above in your browser using DataLab