Learn R Programming

spc (version 0.5.2)

sewma.sf.prerun: Compute the survival function of EWMA run length

Description

Computation of the survival function of the Run Length (RL) for EWMA control charts monitoring normal variance.

Usage

sewma.sf.prerun(n, l, cl, cu, sigma, df1, df2, hs=1, sided="upper",
qm=30, qm.sigma=30, truncate=1e-10, tail_approx=TRUE)

Arguments

n
calculate sf up to value n.
l
smoothing parameter lambda of the EWMA control chart.
cl
lower control limit of the EWMA control chart.
cu
upper control limit of the EWMA control chart.
sigma
true standard deviation.
df1
actual degrees of freedom, corresponds to subgroup size (for known mean it is equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
df2
degrees of freedom of the pre-run variance estimator.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts by choosing "upper" (upper chart without reflection at cl -- the actual value of cl is not used), "Rupper" (upper chart with
qm
number of quadrature nodes for calculating the collocation definite integrals.
qm.sigma
number of quadrature nodes for convoluting the standard deviation uncertainty.
truncate
size of truncated tail.
tail_approx
Controls whether the geometric tail approximation is used (is faster) or not.

Value

  • Returns a vector which resembles the survival function up to a certain point.

Details

The survival function P(L>n) and derived from it also the cdf P(L

References

S. Knoth (2007), Accurate ARL calculation for EWMA control charts monitoring simultaneously normal mean and variance, Sequential Analysis 26, 251-264.

K.-H. Waldmann (1986), Bounds for the distribution of the run length of geometric moving average charts, Appl. Statist. 35, 151-158.

See Also

sewma.sf for the RL survival function of EWMA control charts w/o pre-run uncertainty.

Examples

Run this code
## Knoth (2014?)

Run the code above in your browser using DataLab