xewma.arl.f: Compute ARL function of EWMA control charts
Description
Computation of the (zero-state) Average Run Length (ARL) function for different types of EWMA control charts monitoring normal mean.
Usage
xewma.arl.f(l,c,mu,zr=0,sided="one",limits="fix",r=40)
Arguments
l
smoothing parameter lambda of the EWMA control chart.
c
critical value (similar to alarm limit) of the EWMA control chart.
zr
reflection border for the one-sided chart.
sided
distinguishes between one- and two-sided EWMA control chart by choosing "one" and "two", respectively.
limits
distinguishes between different control limits behavior.
r
number of quadrature nodes, dimension of the resulting linear equation system is equal to r+1 (one-sided) or r (two-sided).
Value
It returns a function of a single argument, hs=x which maps the head-start value hs to the ARL.
Details
It is a convenience function to yield the ARL as function of the head start hs. For more details see xewma.arl.
References
S. V. Crowder (1987),
A simple method for studying run-length distributions of exponentially weighted moving average charts,
Technometrics 29, 401-407.
See Also
xewma.arl for zero-state ARL for one specific head-start hs.