Usage
xsewma.crit(lx, ls, L0, df, mu0=0, sigma0=1, cu=NULL, hsx=0, hss=1, s2.on=TRUE, sided="upper", mode="fixed", Nx=20, Ns=40, qm=30)
Arguments
lx
smoothing parameter lambda of the two-sided mean EWMA chart.
ls
smoothing parameter lambda of the variance EWMA chart.
sigma0
in-control standard deviation.
cu
for two-sided (sided="two") and fixed upper
control limit (mode="fixed") a value larger than sigma0
has to been given, for all other cases cu is ignored.
hsx
so-called headstart (enables fast initial response) of the mean chart --
do not confuse with the true FIR feature considered in xewma.arl; will be updated.
hss
headstart (enables fast initial response) of the variance chart.
df
actual degrees of freedom, corresponds to batch size (for known mean it is equal to the batch size,
for unknown mean it is equal to batch size minus one.
s2.on
distinguishes between $S^2$ and $S$ chart.
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts
by choosing "upper" (upper chart without reflection at cl -- the actual value of
cl is not used), "Rupper" (upper chart with r
mode
only deployed for sided="two" -- with "fixed"
an upper control limit (see cu) is set and only the lower is
determined to obtain the in-control ARL L0, while with "unbiased"
a ce
Nx
dimension of the approximating matrix of the mean chart.
Ns
dimension of the approximating matrix of the variance chart.
qm
number of quadrature nodes used for the collocation integrals.