xsewma.q(lx, cx, ls, csu, df, alpha, mu, sigma, hsx=0,
Nx=40, csl=0, hss=1, Ns=40, sided="upper", qm=30)xsewma.q.crit(lx, ls, L0, alpha, df, mu0=0, sigma0=1, csu=NULL,
hsx=0, hss=1, sided="upper", mode="fixed", Nx=20, Ns=40, qm=30,
c.error=1e-12, a.error=1e-9)
sided="two") and fixed upper
control limit (mode="fixed", only for xsewma.q.crit)
a value larger than sigma0
has to been given, for all other cases cualpha.sided is "upper"."upper" (upper chart without
reflection at cl -- the actual value of of cl is not used).sided="two" -- with "fixed"
an upper control limit (see cu) is set and only the lower is
determined to obtain the in-control ARL L0, while with "unbiased"
a cealpha during
applying the secant rule.alpha and
the critical value of the two-sided mean EWMA chart and
the lower and upper controls limit csl and csu of the
variance EWMA chart, respectively.xsewma.q.crit determines the critical values (similar to alarm limits)
for given in-control RL quantile L0 at level alpha by applying secant
rule and using xsewma.sf().
In case of sided="two" and mode="unbiased"
a two-dimensional secant rule is applied that also ensures that the
maximum of the RL cdf for given standard deviation is attained at sigma0.xsewma.arl for calculation of ARL of simultaneous EWMA charts and
xsewma.sf for the RL survival function.