Learn R Programming

spc (version 0.5.2)

xsewma.sf: Compute the survival function of simultaneous EWMA control charts (mean and variance charts)

Description

Computation of the survival function of the Run Length (RL) for EWMA control charts monitoring simultaneously normal mean and variance.

Usage

xsewma.sf(n, lx, cx, ls, csu, df, mu, sigma, hsx=0, Nx=40,
csl=0, hss=1, Ns=40, sided="upper", qm=30)

Arguments

n
calculate sf up to value n.
lx
smoothing parameter lambda of the two-sided mean EWMA chart.
cx
control limit of the two-sided mean EWMA control chart.
ls
smoothing parameter lambda of the variance EWMA chart.
csu
upper control limit of the variance EWMA control chart.
df
actual degrees of freedom, corresponds to subgroup size (for known mean it is equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
mu
true mean.
sigma
true standard deviation.
hsx
so-called headstart (enables fast initial response) of the mean chart -- do not confuse with the true FIR feature considered in xewma.arl; will be updated.
Nx
dimension of the approximating matrix of the mean chart.
csl
lower control limit of the variance EWMA control chart; default value is 0; not considered if sided is "upper".
hss
headstart (enables fast initial response) of the variance chart.
Ns
dimension of the approximating matrix of the variance chart.
sided
distinguishes between one- and two-sided two-sided EWMA-$S^2$ control charts by choosing "upper" (upper chart without reflection at cl -- the actual value of cl is not used), "Rupper" (upper chart with r
qm
number of quadrature nodes used for the collocation integrals.

Value

  • Returns a vector which resembles the survival function up to a certain point.

Details

The survival function P(L>n) and derived from it also the cdf P(L

References

S. Knoth (2007), Accurate ARL calculation for EWMA control charts monitoring simultaneously normal mean and variance, Sequential Analysis 26, 251-264.

K.-H. Waldmann (1986), Bounds for the distribution of the run length of geometric moving average charts, Appl. Statist. 35, 151-158.

See Also

xsewma.arl for zero-state ARL computation of simultaneous EWMA control charts.

Examples

Run this code
## Knoth (2014?)

Run the code above in your browser using DataLab