sewma.crit.prerun(l,L0,df1,df2,sigma0=1,cl=NULL,cu=NULL,hs=1,sided="upper",
mode="fixed",r=40,qm=30,qm.sigma=30,truncate=1e-10,
tail_approx=TRUE,c.error=1e-10,a.error=1e-9)sided="Rupper", that is, upper variance control chart with lower
reflecting barrier cl.sided="two") and fixed upper control limit
(mode="fixed") a value larger than sigma0
has to been given, for all other cases cu is ignored."upper" (upper chart without reflection at cl -- the actual value of cl
is not used), "Rupper" (upper chart with rsided="two" -- with "fixed" an upper control limit
(see cu) is set and only the lower is calculated to obtain the in-control ARL L0, while
with "unbiased" a cealpha during applying the secant rule.cl and cu.sewma.crit.prerun determines the critical values (similar to alarm limits)
for given in-control ARL L0
by applying secant rule and using sewma.arl.prerun().
In case of sided="two" and mode="unbiased"
a two-dimensional secant rule is applied that also ensures that the
maximum of the ARL function for given standard deviation is attained
at sigma0. See Knoth (2010) for some details of the algorithm involved.S. Knoth (2010), Control Charting Normal Variance -- Reflections, Curiosities, and Recommendations, in Frontiers in Statistical Quality Control 9, H.-J. Lenz and P.-T. Wilrich (Eds.), Physica Verlag, Heidelberg, Germany, 3-18.
sewma.arl.prerun for calculation of ARL of variance charts under
pre-run uncertainty and sewma.crit for
the algorithm w/o pre-run uncertainty.