Usage
sewma.sf(n, l, cl, cu, sigma, df, hs=1, sided="upper", r=40, qm=30)
Arguments
n
calculate sf up to value n.
l
smoothing parameter lambda of the EWMA control chart.
cl
lower control limit of the EWMA control chart.
cu
upper control limit of the EWMA control chart.
sigma
true standard deviation.
df
actual degrees of freedom, corresponds to subgroup size
(for known mean it is equal to the subgroup size,
for unknown mean it is equal to subgroup size minus one.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided
EWMA-$S^2$ control charts
by choosing "upper" (upper chart without reflection at cl --
the actual value of cl is not used),
"Rupper" (upper chart with
r
dimension of the resulting linear equation system
(highest order of the collocation polynomials).
qm
number of quadrature nodes for calculating the
collocation definite integrals.