Usage
sewma.sf.prerun(n, l, cl, cu, sigma, df1, df2, hs=1, sided="upper",
qm=30, qm.sigma=30, truncate=1e-10, tail_approx=TRUE)
Arguments
n
calculate sf up to value n.
l
smoothing parameter lambda of the EWMA control chart.
cl
lower control limit of the EWMA control chart.
cu
upper control limit of the EWMA control chart.
sigma
true standard deviation.
df1
actual degrees of freedom, corresponds to subgroup size
(for known mean it is equal to the subgroup size,
for unknown mean it is equal to subgroup size minus one.
df2
degrees of freedom of the pre-run variance estimator.
hs
so-called headstart (enables fast initial response).
sided
distinguishes between one- and two-sided two-sided
EWMA-$S^2$ control charts
by choosing "upper" (upper chart without reflection at cl --
the actual value of cl is not used),
"Rupper" (upper chart with
qm
number of quadrature nodes for calculating the collocation
definite integrals.
qm.sigma
number of quadrature nodes for convoluting the
standard deviation uncertainty.
truncate
size of truncated tail.
tail_approx
Controls whether the geometric tail approximation
is used (is faster) or not.