Usage
xsewma.sf(n, lx, cx, ls, csu, df, mu, sigma, hsx=0, Nx=40,
csl=0, hss=1, Ns=40, sided="upper", qm=30)
Arguments
n
calculate sf up to value n.
lx
smoothing parameter lambda of the two-sided mean EWMA chart.
cx
control limit of the two-sided mean EWMA control chart.
ls
smoothing parameter lambda of the variance EWMA chart.
csu
upper control limit of the variance EWMA control chart.
df
actual degrees of freedom, corresponds to subgroup size (for known mean it is
equal to the subgroup size, for unknown mean it is equal to subgroup size minus one.
sigma
true standard deviation.
hsx
so-called headstart (enables fast initial response) of the mean chart --
do not confuse with the true FIR feature considered in xewma.arl; will be updated.
Nx
dimension of the approximating matrix of the mean chart.
csl
lower control limit of the variance EWMA control chart; default value is 0;
not considered if sided is "upper".
hss
headstart (enables fast initial response) of the variance chart.
Ns
dimension of the approximating matrix of the variance chart.
sided
distinguishes between one- and two-sided two-sided
EWMA-$S^2$ control charts by choosing "upper" (upper chart
without reflection at cl -- the actual value of
cl is not used), "Rupper" (upper chart with r
qm
number of quadrature nodes used for the collocation integrals.